@@ -4,7 +4,7 @@ sub p() {
     return 5;
 };
 
-my $x=1; $x=2; 
-$x=3; $x = 4; $x=5;
-$x=6; $x = p(); $x=7;
-$x = 8;
+my $x=1; my $y=2; 
+$x=$y; $y = 4; $x += $y;
+$x=6; $y = p(); my $z = p(); 
+$x = 8 + $y + $z;
