@@ -47,23 +47,23 @@ sub setup()
 	'Comment_POD'      => [$ANSI_colors{'bblue'},    $ANSI_colors{'none'}],
 	'Directive'        => [$ANSI_colors{'magenta'},  $ANSI_colors{'none'}],
 	'Label'            => [$ANSI_colors{'magenta'},  $ANSI_colors{'none'}],
-	'Quote'            => [$ANSI_colors{'bwhite'},   $ANSI_colors{'none'}],
+	'Quote'            => [$ANSI_colors{'black'},    $ANSI_colors{'none'}],
 	'String'           => [$ANSI_colors{'bcyan'},    $ANSI_colors{'none'}],
-	'Subroutine'       => [$ANSI_colors{'byellow'},  $ANSI_colors{'none'}],
+	'Subroutine'       => [$ANSI_colors{'bblue'},    $ANSI_colors{'none'}],
 	'Variable_Scalar'  => [$ANSI_colors{'bgreen'},   $ANSI_colors{'none'}],
 	'Variable_Array'   => [$ANSI_colors{'bgreen'},   $ANSI_colors{'none'}],
 	'Variable_Hash'    => [$ANSI_colors{'bgreen'},   $ANSI_colors{'none'}],
-	'Variable_Typeglob'=> [$ANSI_colors{'bwhite'},   $ANSI_colors{'none'}],
+	'Variable_Typeglob'=> [$ANSI_colors{'black'},    $ANSI_colors{'none'}],
 	'Whitespace'       => ['',                       ''                  ],
 	'Character'        => [$ANSI_colors{'bred'},     $ANSI_colors{'none'}],
-	'Keyword'          => [$ANSI_colors{'bwhite'},   $ANSI_colors{'none'}],
+	'Keyword'          => [$ANSI_colors{'black'},    $ANSI_colors{'none'}],
 	'Builtin_Function' => [$ANSI_colors{'bwhite'},   $ANSI_colors{'none'}],
-	'Builtin_Operator' => [$ANSI_colors{'bwhite'},   $ANSI_colors{'none'}],
-	'Operator'         => [$ANSI_colors{'white'},    $ANSI_colors{'none'}],
+	'Builtin_Operator' => [$ANSI_colors{'black'},    $ANSI_colors{'none'}],
+	'Operator'         => [$ANSI_colors{'black'},    $ANSI_colors{'none'}],
 	'Bareword'         => [$ANSI_colors{'white'},    $ANSI_colors{'none'}],
 	'Package'          => [$ANSI_colors{'green'},    $ANSI_colors{'none'}],
 	'Number'           => [$ANSI_colors{'bmagenta'}, $ANSI_colors{'none'}],
-	'Symbol'           => [$ANSI_colors{'white'},    $ANSI_colors{'none'}],
+	'Symbol'           => [$ANSI_colors{'gray'},     $ANSI_colors{'none'}],
 	'CodeTerm'         => [$ANSI_colors{'gray'},     $ANSI_colors{'none'}],
 	'DATA'             => [$ANSI_colors{'gray'},     $ANSI_colors{'none'}],
 	
